#!/usr/bin/env python
# -*- coding: utf-8 -*-

#   Copyright 2009 Luca Beltrame <einar@heavensinferno.net>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License, under
#   version 2 of the License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the
#   Free Software Foundation, Inc.,
#   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

'''
File: connectdialog.py
Author: Luca Beltrame
Description: File to handle connections to Danbooru sites.
'''

from PyQt4.QtCore import QSize
from PyQt4.QtGui import QWidget, QPixmap
from PyKDE4.kdecore import KUrl, KGlobal, KComponentData
from PyKDE4.kdeui import KDialog, KNotification, KIcon

import api.remote as remote
from  ui.ui_connectdialog import Ui_connectForm


class ConnectWidget(QWidget, Ui_connectForm):

    "Widget used in the dialog for a Danbooru connection."

    def __init__(self, urls=None, parent=None):

        super(ConnectWidget, self).__init__(parent)
        self.setupUi(self)
        self.danbooruUrlComboBox.setFocus()

        if urls is not None:
            for index, item in enumerate(urls):
                self.danbooruUrlComboBox.insertUrl(index, KUrl(item))

    @property
    def url(self):

        "Returns the currently selected Danbooru URL."

        return self.danbooruUrlComboBox.currentText()

    @property
    def username(self):

        "Returns the inserted username."

        return self.userLineEdit.text()

    @property
    def password(self):

        "Returns the inserted password."

        return self.passwdLineEdit.text()


class ConnectDialog(KDialog):

    """Dialog used to "connect" to a Danbooru board. It performs validation of
    the used URLs and stores an API instance if successful, which can be
    retrieved by other objects by calling the danbooru_api() function."""

    def __init__(self, urls=None, parent=None):

        super(ConnectDialog, self).__init__(parent)

        self.connection__connection = None

        self.connect_widget = ConnectWidget(urls, self)
        self.setMainWidget(self.connect_widget)
        self.setButtons(KDialog.ButtonCode(KDialog.Ok | KDialog.Cancel))
        self.setCaption("Enter a Danbooru URL")
        self.adjustSize()

    def _response(self, result):

        "Checks if there's an error prior to accepting the dialog."

        if not result:
            return
        else:
            KDialog.accept(self)

    def accept(self):

        url = self.connect_widget.url
        login = self.connect_widget.username
        password = self.connect_widget.password

        username = None if login.isEmpty() else login
        password = None if password.isEmpty() else password

        if url.isEmpty():
            return

        self.__connection = remote.DanbooruService(unicode(url), username,
                                              password=password)

        KDialog.accept(self)

    @property
    def danbooru_connection(self):

        "Returns the Danbooru object retrieved."

        if self.__connection is None:
            return

        return self.__connection
